import { ISignal } from '@lumino/signaling';
import { IOutput } from '@jupyterlab/nbformat';
import { IOutputAreaModel } from '@jupyterlab/outputarea';
import { Kernel as JupyterKernel, KernelMessage } from '@jupyterlab/services';
export type IOPubMessageHook = (msg: KernelMessage.IIOPubMessage) => boolean | PromiseLike<boolean>;
export type ShellMessageHook = (msg: KernelMessage.IShellMessage) => boolean | PromiseLike<boolean>;
/**
 * KernelExecutor options
 */
export type IKernelExecutorOptions = {
    /**
     * Kernel connection
     */
    connection: JupyterKernel.IKernelConnection;
    /**
     * Outputs model to populate with the execution results.
     */
    model?: IOutputAreaModel;
};
export declare class KernelExecutor {
    private _executed;
    private _kernelConnection;
    private _kernelState;
    private _model;
    private _modelChanged;
    private _outputs;
    private _stopOnError;
    private _outputsChanged;
    private _future?;
    private _shellMessageHooks;
    constructor({ connection, model }: IKernelExecutorOptions);
    /**
     * Execute a code snippet.
     *
     * @param code Code to be executed
     * @param options Callbacks on IOPub messages and on reply message
     * @returns The outputs model
     *
     * @example
     * Here is an example to execute the code snippet `print('hello')`.
     *
     * ```ts
     * const executor = new KernelExecutor(kernelConnection);
     * const outputs = await executor.execute("print('hello')");
     * ```
     */
    execute(code: string, { iopubMessageHooks, shellMessageHooks, silent, stopOnError, storeHistory, allowStdin, }?: {
        iopubMessageHooks?: IOPubMessageHook[];
        shellMessageHooks?: ShellMessageHook[];
        silent?: boolean;
        stopOnError?: boolean;
        storeHistory?: boolean;
        allowStdin?: boolean;
    }): Promise<IOutputAreaModel>;
    /**
     * Clear the kernel executor previous results.
     */
    clear(): void;
    registerIOPubMessageHook: (msg: IOPubMessageHook) => void;
    /**
     *
     */
    get future(): JupyterKernel.IFuture<KernelMessage.IExecuteRequestMsg, KernelMessage.IExecuteReplyMsg> | undefined;
    /**
     * Promise that resolves when the execution is done.
     */
    get done(): Promise<void>;
    /**
     * Code execution result as serialized JSON
     */
    get result(): Promise<string>;
    /**
     * Kernel outputs emitted.
     */
    get outputs(): IOutput[];
    /**
     * Kernel outputs wrapped in a model.
     */
    get model(): IOutputAreaModel;
    /**
     * Signal emitted when the outputs list changes.
     */
    get outputsChanged(): ISignal<KernelExecutor, IOutput[]>;
    /**
     * Signal emitted when the outputs model changes.
     */
    get modelChanged(): ISignal<KernelExecutor, IOutputAreaModel>;
    private _onIOPub;
    private _onReply;
}
export default KernelExecutor;
