/*
 * Copyright (c) 2021-2023 Datalayer, Inc.
 *
 * MIT License
 */
import { PromiseDelegate } from '@lumino/coreutils';
import { Signal } from '@lumino/signaling';
import { OutputAreaModel } from '@jupyterlab/outputarea';
import { KernelMessage } from '@jupyterlab/services';
import { outputsAsString } from '../../utils/Utils';
import { ExecutionPhase, kernelsStore } from './KernelState';
import { toKernelState } from '../../components/kernel';
export class KernelExecutor {
    _executed;
    _kernelConnection;
    _kernelState;
    _model;
    _modelChanged = new Signal(this);
    _outputs;
    _stopOnError;
    _outputsChanged = new Signal(this);
    _future;
    _shellMessageHooks = new Array();
    constructor({ connection, model }) {
        this._executed = new PromiseDelegate();
        this._kernelConnection = connection;
        this._model = model ?? new OutputAreaModel();
        this._outputs = [];
        this._kernelState = kernelsStore.getState();
    }
    /**
     * Execute a code snippet.
     *
     * @param code Code to be executed
     * @param options Callbacks on IOPub messages and on reply message
     * @returns The outputs model
     *
     * @example
     * Here is an example to execute the code snippet `print('hello')`.
     *
     * ```ts
     * const executor = new KernelExecutor(kernelConnection);
     * const outputs = await executor.execute("print('hello')");
     * ```
     */
    execute(code, { iopubMessageHooks = [], shellMessageHooks = [], silent = false, stopOnError = false, storeHistory = true, allowStdin = false, } = {}) {
        this._stopOnError = stopOnError;
        this._shellMessageHooks = shellMessageHooks;
        kernelsStore.getState().setExecutionPhase(this._kernelConnection.id, ExecutionPhase.running);
        this._future = this._kernelConnection.requestExecute({
            code,
            allow_stdin: allowStdin,
            silent,
            stop_on_error: stopOnError,
            store_history: storeHistory,
        });
        this._future.onIOPub = this._onIOPub;
        this._future.onReply = this._onReply;
        iopubMessageHooks.forEach(hook => this._future.registerMessageHook(hook));
        this._future.onStdin = msg => {
            if (KernelMessage.isInputRequestMsg(msg)) {
                // FIXME Implement this.
                // this.onInputRequest(msg, value);
            }
        };
        // Wait for future to be done before resolving the exectud promise.
        this._future.done.then(() => {
            kernelsStore.getState().setExecutionPhase(this._kernelConnection.id, ExecutionPhase.completed);
            this._executed.resolve(this._model);
        });
        return this._executed.promise;
    }
    /**
     * Clear the kernel executor previous results.
     */
    clear() {
        this._shellMessageHooks.length = 0;
        this._outputs.length = 0;
        this._model.clear();
    }
    registerIOPubMessageHook = (msg) => {
        this._future?.registerMessageHook(msg);
    };
    /**
     *
     */
    get future() {
        return this._future;
    }
    /**
     * Promise that resolves when the execution is done.
     */
    get done() {
        return this._executed.promise.then(() => {
            return;
        });
    }
    /**
     * Code execution result as serialized JSON
     */
    get result() {
        return this._executed.promise.then(model => {
            return outputsAsString(model.toJSON());
        });
    }
    /**
     * Kernel outputs emitted.
     */
    get outputs() {
        return this._outputs;
    }
    /**
     * Kernel outputs wrapped in a model.
     */
    get model() {
        return this._model;
    }
    /**
     * Signal emitted when the outputs list changes.
     */
    get outputsChanged() {
        0;
        return this._outputsChanged;
    }
    /**
     * Signal emitted when the outputs model changes.
     */
    get modelChanged() {
        return this._modelChanged;
    }
    _onIOPub = (message) => {
        if (this._future?.msg.header.msg_id !== message.parent_header.msg_id) {
            return;
        }
        console.debug('Kernel IOPub message', message);
        const messageType = message.header.msg_type;
        const output = { ...message.content, output_type: messageType };
        switch (messageType) {
            case 'execute_result':
                this._outputs.push(message.content);
                this._outputsChanged.emit(this._outputs);
                this._model.add(output);
                this._modelChanged.emit(this._model);
                break;
            case 'display_data':
                this._outputs.push(message.content);
                this._outputsChanged.emit(this._outputs);
                this._model.add(output);
                this._modelChanged.emit(this._model);
                break;
            case 'stream':
            case 'error':
                this._outputs.push(message.content);
                this._outputsChanged.emit(this._outputs);
                this._model.add(output);
                this._modelChanged.emit(this._model);
                if (this._stopOnError) {
                    kernelsStore.getState().setExecutionPhase(this._kernelConnection.id, ExecutionPhase.completed_with_error);
                }
                break;
            case 'clear_output':
                const wait = message.content.wait;
                this._model.clear(wait);
                break;
            case 'update_display_data':
                this._outputs.push(message.content);
                this._outputsChanged.emit(this._outputs);
                // FIXME this needs more advanced analysis see OutputArea
                this._model.add(output);
                this._modelChanged.emit(this._model);
                break;
            case 'status':
                const executionState = message.content.execution_state;
                const connectionStatus = this._kernelConnection.connectionStatus;
                const kernelState = toKernelState(connectionStatus, executionState);
                this._kernelState.setExecutionState(this._kernelConnection.id, kernelState);
                break;
            default:
                break;
        }
    };
    _onReply = (message) => {
        if (this._future?.msg.header.msg_id !== message.parent_header.msg_id) {
            return;
        }
        console.debug('Kernel Reply message', message);
        this._shellMessageHooks.forEach(hook => hook(message));
        const content = message.content;
        if (content.status !== 'ok') {
            switch (content.status) {
                case 'abort':
                    this._executed.reject('Execution aborted.');
                    break;
                case 'error':
                    {
                        const { ename, evalue, traceback } = content;
                        this._executed.reject(`${ename}: ${evalue}\n${(traceback ?? []).join('\n')}`);
                    }
                    break;
            }
            return;
        }
        // API responses that contain a pager are special cased and their type
        // is overridden from 'execute_reply' to 'display_data' in order to
        // render output.
        const payload = content?.payload;
        if (payload?.length) {
            const pages = payload.filter((i) => i.source === 'page');
            if (pages.length) {
                const page = JSON.parse(JSON.stringify(pages[0]));
                const output = {
                    output_type: 'display_data',
                    data: page.data,
                    metadata: {},
                };
                this._outputs.push(output);
                this._outputsChanged.emit(this._outputs);
                this._model.add(output);
                this._modelChanged.emit(this._model);
            }
        }
    };
}
export default KernelExecutor;
//# sourceMappingURL=KernelExecutor.js.map